From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
To: linux-kernel@vger.kernel.org
Cc: Greg Kroah-Hartman <gregkh@linuxfoundation.org>,
stable@vger.kernel.org, Dave Jones <davej@codemonkey.org.uk>,
Mike Snitzer <snitzer@redhat.com>,
Zdenek Kabelac <zkabelac@redhat.com>,
Mikulas Patocka <mpatocka@redhat.com>
Subject: [PATCH 5.10 2/2] Revert "dm raid: fix discard limits for raid1 and raid10"
Date: Mon, 14 Dec 2020 18:06:11 +0100 [thread overview]
Message-ID: <20201214170452.896511308@linuxfoundation.org> (raw)
In-Reply-To: <20201214170452.563016590@linuxfoundation.org>
From: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
This reverts commit e0910c8e4f87bb9f767e61a778b0d9271c4dc512.
It causes problems :(
Reported-by: Dave Jones <davej@codemonkey.org.uk>
Reported-by: Mike Snitzer <snitzer@redhat.com>
Cc: Zdenek Kabelac <zkabelac@redhat.com>
Cc: Mikulas Patocka <mpatocka@redhat.com>
Cc: Linus Torvalds <torvalds@linux-foundation.org
Signed-off-by: Greg Kroah-Hartman <gregkh@linuxfoundation.org>
---
drivers/md/dm-raid.c | 12 +++++-------
1 file changed, 5 insertions(+), 7 deletions(-)
--- a/drivers/md/dm-raid.c
+++ b/drivers/md/dm-raid.c
@@ -3730,14 +3730,12 @@ static void raid_io_hints(struct dm_targ
blk_limits_io_opt(limits, chunk_size_bytes * mddev_data_stripes(rs));
/*
* RAID10 personality requires bio splitting,
* RAID0/1/4/5/6 don't and process large discard bios properly.
*/
- if (rs_is_raid10(rs)) {
- limits->discard_granularity = max(chunk_size_bytes,
- limits->discard_granularity);
- limits->max_discard_sectors = min_not_zero(rs->md.chunk_sectors,
- limits->max_discard_sectors);
+ if (rs_is_raid1(rs) || rs_is_raid10(rs)) {
+ limits->discard_granularity = chunk_size_bytes;
+ limits->max_discard_sectors = rs->md.chunk_sectors;
}
}
next prev parent reply other threads:[~2020-12-14 17:06 UTC|newest]
Thread overview: 11+ messages / expand[flat|nested] mbox.gz Atom feed top
2020-12-14 17:06 [PATCH 5.10 0/2] 5.10.1-rc1 review Greg Kroah-Hartman
2020-12-14 17:06 ` [PATCH 5.10 1/2] Revert "md: change mddev chunk_sectors from int to unsigned" Greg Kroah-Hartman
2020-12-14 17:06 ` Greg Kroah-Hartman [this message]
2020-12-14 22:20 ` [PATCH 5.10 0/2] 5.10.1-rc1 review Shuah Khan
2020-12-15 9:24 ` Greg Kroah-Hartman
2020-12-15 9:20 ` Jon Hunter
2020-12-15 9:29 ` Greg Kroah-Hartman
2020-12-15 10:20 ` Naresh Kamboju
2020-12-15 10:27 ` Greg Kroah-Hartman
2020-12-15 20:32 ` Guenter Roeck
2020-12-16 9:47 ` Greg Kroah-Hartman
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=20201214170452.896511308@linuxfoundation.org \
--to=gregkh@linuxfoundation.org \
--cc=davej@codemonkey.org.uk \
--cc=linux-kernel@vger.kernel.org \
--cc=mpatocka@redhat.com \
--cc=snitzer@redhat.com \
--cc=stable@vger.kernel.org \
--cc=zkabelac@redhat.com \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -3730,14 +3730,12 @@ static void raid_io_hints(struct dm_targ
blk_limits_io_opt(limits, chunk_size_bytes * mddev_data_stripes(rs));
/*
- * RAID10 personality requires bio splitting,
- * RAID0/1/4/5/6 don't and process large discard bios properly.
+ * RAID1 and RAID10 personalities require bio splitting,
+ * RAID0/4/5/6 don't and process large discard bios properly.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.